==> logicmonitor_sdk-python-3.0.208.tar.gz: python/docs/Alert.md <==
# Alert

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**resource_id** | **int** | The device specific LogicModule Id | [optional] 
**end_epoch** | **int** | The time (in epoch format) that the alert ended | [optional] 
**threshold** | **str** | The threshold associated with the object in alert | [optional] 
**type** | **str** | The type of alert | [optional] 
**start_epoch** | **int** | The time (in epoch format) that the alert started | [optional] 
**enable_anomaly_alert_generation** | **str** | Indicates dynamic threshold alert generation setting. Expression is comma separated 0 denotes OFF, 1 denotes ON, -1 denotes INVALID 1,0,1 &#x3D;   warn : ON     error: OFF   critical: ON Empty value on this parameter means : 0,0,0 | [optional] 
**internal_id** | **str** | The internal id for the alert | [optional] 
**monitor_object_name** | **str** | The name of the object that the alert is associated with | [optional] 
**data_point_name** | **str** | The name of the datapoint in alert | [optional] 
**data_point_id** | **int** | The id of the datapoint in alert | [optional] 
**suppressor** | **str** | The component (For example: SDT, HostClusterAlert) which suppressed the alert | [optional] 
**id** | **str** | The alert id | [optional] 
**detail_message** | **object** | The alert message, if needMessage&#x3D;true is included in the query parameters | [optional] 
**rule_id** | **int** | The id of the rule the alert matches | [optional] 
**alert_external_ticket_url** | [**JSONObject**](JSONObject.md) | The alert external ticket urls | [optional] 
**tenant** | **str** | Tenant to which this alert belongs to.  | [optional] 
**alert_value** | **str** | The value that triggered the alert | [optional] 
**sdted** | **bool** | It specifies if the SDT is set for an active alert or not. However, the sdted is set to false for cleared alert as you cannot apply SDT to a cleared alert. | [optional] 
**sdt** | **object** | The active SDT, if one exists | [optional] 
**enable_anomaly_alert_suppression** | **str** | Indicates anomaly detection alert suppression setting, expression is comma separated 0 denotes OFF, 1 denotes ON, -1 denotes INVALID 1,0,1 &#x3D;   warn : ON     error: OFF   critical: ON Empty value on this parameter means : 0,0,0 | [optional] 
**received_list** | **str** | The recipients that have received the alert | [optional] 
**monitor_object_groups** | **object** | Information about the groups the object is a member of | [optional] 
**chain_id** | **int** | The id of the escalation chain the alert was routed to | [optional] 
**resource_template_id** | **int** | The id of the datasource in alert | [optional] 
**cleared** | **bool** | Whether or not the alert has cleared | [optional] 
**ad_alert_desc** | **str** | The description for dynamic threshold based alert | [optional] 
**resource_template_name** | **str** | The name of the datasource in alert | [optional] 
**anomaly** | **bool** | Indicates the anomaly alert, value can be true/false/null. If alert value lies within confidence band then false, otherwise true. If confidence band is not available then value will be null. | [optional] 
**instance_name** | **str** | The name of the instance in alert | [optional] 
**monitor_object_id** | **int** | The id of the object that the alert is associated with | [optional] 
**rule** | **str** | The rule the alert matches | [optional] 
**ack_comment** | **str** | The comment submitted with the acknowledgement | [optional] 
**alert_group_entity_value** | **str** | Alert group entity value for stateful log alerts | [optional] 
**instance_id** | **int** | The id of the instance in alert | [optional] 
**suppress_desc** | **str** | The description for suppressed alert | [optional] 
**next_recipient** | **int** | The next recipient in the escalation chain for this alert | [optional] 
**ad_alert** | **bool** | Specifies whether alert is dynamic threshold based or not | [optional] 
**acked_by** | **str** | The user that acknowledged the alert | [optional] 
**severity** | **int** | The alert severity, where 2&#x3D;warning, 3&#x3D;error and 4&#x3D;critical | [optional] 
**acked_epoch** | **int** | The time (in epoch format) that the alert was acknowledged | [optional] 
**chain** | **str** | The escalation chain the alert was routed to | [optional] 
**sub_chain_id** | **int** | The id of the sub time based chain | [optional] 
**log_meta_data** | **str** | Specified log alert metadata fields value | [optional] 
**monitor_object_type** | **str** |  | [optional] 
**acked** | **bool** | Whether or not the alert has been acknowledged | [optional] 
**resource_template_type** | **str** | The type of the logicmodule in alert | [optional] 
**clear_value** | **str** | The value that cleared the alert | [optional] 
**instance_description** | **str** | The description of the instance in alert | [optional] 
**dependency_routing_state** | **str** | The dependency routing state | [optional] 
**dependency_role** | **str** | The dependency role | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

==> logicmonitor_sdk-python-3.0.213.tar.gz: python/docs/Alert.md <==
# Alert

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**resource_id** | **int** | The device specific LogicModule Id | [optional] 
**end_epoch** | **int** | The time (in epoch format) that the alert ended | [optional] 
**threshold** | **str** | The threshold associated with the object in alert | [optional] 
**type** | **str** | The type of alert | [optional] 
**start_epoch** | **int** | The time (in epoch format) that the alert started | [optional] 
**enable_anomaly_alert_generation** | **str** | Indicates dynamic threshold alert generation setting. Expression is comma separated 0 denotes OFF, 1 denotes ON, -1 denotes INVALID 1,0,1 &#x3D;   warn : ON     error: OFF   critical: ON Empty value on this parameter means : 0,0,0 | [optional] 
**internal_id** | **str** | The internal id for the alert | [optional] 
**monitor_object_name** | **str** | The name of the object that the alert is associated with | [optional] 
**data_point_name** | **str** | The name of the datapoint in alert | [optional] 
**data_point_id** | **int** | The id of the datapoint in alert | [optional] 
**suppressor** | **str** | The component (For example: SDT, HostClusterAlert) which suppressed the alert | [optional] 
**id** | **str** | The alert id | [optional] 
**detail_message** | **object** | The alert message, if needMessage&#x3D;true is included in the query parameters | [optional] 
**rule_id** | **int** | The id of the rule the alert matches | [optional] 
**alert_external_ticket_url** | [**JSONObject**](JSONObject.md) |  | [optional] 
**tenant** | **str** | Tenant to which this alert belongs to.  | [optional] 
**alert_value** | **str** | The value that triggered the alert | [optional] 
**sdted** | **bool** | It specifies if the SDT is set for an active alert or not. However, the sdted is set to false for cleared alert as you cannot apply SDT to a cleared alert. | [optional] 
**sdt** | **object** | The active SDT, if one exists | [optional] 
**enable_anomaly_alert_suppression** | **str** | Indicates anomaly detection alert suppression setting, expression is comma separated 0 denotes OFF, 1 denotes ON, -1 denotes INVALID 1,0,1 &#x3D;   warn : ON     error: OFF   critical: ON Empty value on this parameter means : 0,0,0 | [optional] 
**received_list** | **str** | The recipients that have received the alert | [optional] 
**monitor_object_groups** | **object** | Information about the groups the object is a member of | [optional] 
**chain_id** | **int** | The id of the escalation chain the alert was routed to | [optional] 
**resource_template_id** | **int** | The id of the datasource in alert | [optional] 
**cleared** | **bool** | Whether or not the alert has cleared | [optional] 
**ad_alert_desc** | **str** | The description for dynamic threshold based alert | [optional] 
**resource_template_name** | **str** | The name of the datasource in alert | [optional] 
**anomaly** | **bool** | Indicates the anomaly alert, value can be true/false/null. If alert value lies within confidence band then false, otherwise true. If confidence band is not available then value will be null. | [optional] 
**instance_name** | **str** | The name of the instance in alert | [optional] 
**monitor_object_id** | **int** | The id of the object that the alert is associated with | [optional] 
**rule** | **str** | The rule the alert matches | [optional] 
**ack_comment** | **str** | The comment submitted with the acknowledgement | [optional] 
**alert_group_entity_value** | **str** | Alert group entity value for stateful log alerts | [optional] 
**instance_id** | **int** | The id of the instance in alert | [optional] 
**suppress_desc** | **str** | The description for suppressed alert | [optional] 
**next_recipient** | **int** | The next recipient in the escalation chain for this alert | [optional] 
**ad_alert** | **bool** | Specifies whether alert is dynamic threshold based or not | [optional] 
**acked_by** | **str** | The user that acknowledged the alert | [optional] 
**severity** | **int** | The alert severity, where 2&#x3D;warning, 3&#x3D;error and 4&#x3D;critical | [optional] 
**acked_epoch** | **int** | The time (in epoch format) that the alert was acknowledged | [optional] 
**chain** | **str** | The escalation chain the alert was routed to | [optional] 
**sub_chain_id** | **int** | The id of the sub time based chain | [optional] 
**log_meta_data** | **str** | Specified log alert metadata fields value | [optional] 
**monitor_object_type** | **str** |  | [optional] 
**acked** | **bool** | Whether or not the alert has been acknowledged | [optional] 
**resource_template_type** | **str** | The type of the logicmodule in alert | [optional] 
**clear_value** | **str** | The value that cleared the alert | [optional] 
**instance_description** | **str** | The description of the instance in alert | [optional] 
**dependency_routing_state** | **str** | The dependency routing state | [optional] 
**dependency_role** | **str** | The dependency role | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)
